@@ -14,13 +14,13 @@
 #' area in the map units or km2 for no project raster. Default is TRUE.
 #' 
 #' @param category.name a character vector defining the class names. If NULL
-#' then use the classe names in the object \code{x}. Default is NULL.
+#' the class names in the object \code{x} are used. Default is NULL.
 #' 
 #' @param category.type a character defining the categories type "numeric" 
-#' or "letter", if NULL then use the class names. Default is NULL. 
+#' or "letter", if NULL the class names are used. Default is NULL. 
 #' 
 #' @param conf.int confidence level (0-1) for interval estimation of the population mean.
-#' for details see \code{\link[Hmisc]{smean.cl.normal}}. Used if \code{x} is 
+#' For details see \code{\link[Hmisc]{smean.cl.normal}}. Used if \code{x} is 
 #' \code{\link[dtwSat]{twdtwCrossValidation}}.
 #' 
 #' @return A \link[ggplot2]{ggplot} object.
@@ -28,6 +28,11 @@
 #' @seealso 
 #' \code{\link[dtwSat]{twdtwAssessment}} and \code{\link[dtwSat]{twdtwAssess}}
 #'  
+#' @references
+#'   \insertRef{Maus:2019}{dtwSat}
+#'   
+#'   \insertRef{Maus:2016}{dtwSat}
+#'   
 #' @examples
 #' \dontrun{
 #' 
@@ -49,7 +54,7 @@ plotAccuracy = function(x, perc=TRUE, conf.int=.95, time.labels=NULL,
     if(class(x)=="twdtwAssessment"){
       gp = .plotAssessmentAccuracy(x, perc, time.labels, category.name, category.type)
     } else {
-      stop("class of x is not twdtwAssessment or twdtwCrossValidation")
+      stop("Class of x is not twdtwAssessment or twdtwCrossValidation")
     }
   } 
   
@@ -131,7 +136,7 @@ plotAccuracy = function(x, perc=TRUE, conf.int=.95, time.labels=NULL,
   
   UA = do.call("rbind", lapply(x@accuracy, function(x) data.frame(label="UA", rbind(x$UsersAccuracy))))
   names(UA)[-1] = category.name
-  PA = do.call("rbind", lapply(x@accuracy, function(x) data.frame(label="PA", rbind(x$UsersAccuracy))))
+  PA = do.call("rbind", lapply(x@accuracy, function(x) data.frame(label="PA", rbind(x$ProducersAccuracy))))
   names(PA)[-1] = category.name
   df = melt(rbind(UA,PA), id="label")
   df$label = factor(df$label, levels = c("UA", "PA"), 
